# Directive components in `ngAnimate`

Name | Description
--- | ---
ngAnimateChildren | ngAnimateChildren allows you to specify that children of this element should animate even if any of the children's parents are currently animating. By default, when an element has an active `enter`, `leave`, or `move` (structural) animation, child elements that also have an active structural animation are not animated.
ngAnimateSwap | ngAnimateSwap is a animation-oriented directive that allows for the container to be removed and entered in whenever the associated expression changes. A common usecase for this directive is a rotating banner or slider component which contains one image being present at a time. When the active image changes then the old image will perform a `leave` animation and the new element will be inserted via an `enter` animation.